mriqc.interfaces package — mriqc 0.1.0 documentation

# mriqc.interfaces package

## Submodules

## mriqc.interfaces.qc module

Nipype interfaces to quality control measures

class `mriqc.interfaces.qc.` `FramewiseDisplacement`(**inputs)

  Bases: `nipype.interfaces.base.BaseInterface`

  Computes anatomical QC measures on the structural image given as input

  `input_spec`

    alias of `FramewiseDisplacementInputSpec`

  `output_spec`

    alias of `FramewiseDisplacementOutputSpec`

class `mriqc.interfaces.qc.` `FramewiseDisplacementInputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.BaseInterfaceInputSpec`

class `mriqc.interfaces.qc.` `FramewiseDisplacementOutputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.TraitedSpec`

class `mriqc.interfaces.qc.` `FunctionalQC`(**inputs)

  Bases: `nipype.interfaces.base.BaseInterface`

  Computes anatomical QC measures on the structural image given as input

  `input_spec`

    alias of `FunctionalQCInputSpec`

  `output_spec`

    alias of `FunctionalQCOutputSpec`

class `mriqc.interfaces.qc.` `FunctionalQCInputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.BaseInterfaceInputSpec`

class `mriqc.interfaces.qc.` `FunctionalQCOutputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.TraitedSpec`

class `mriqc.interfaces.qc.` `StructuralQC`(**inputs)

  Bases: `nipype.interfaces.base.BaseInterface`

  Computes anatomical QC measures on the structural image given as input

  `input_spec`

    alias of `StructuralQCInputSpec`

  `output_spec`

    alias of `StructuralQCOutputSpec`

class `mriqc.interfaces.qc.` `StructuralQCInputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.BaseInterfaceInputSpec`

class `mriqc.interfaces.qc.` `StructuralQCOutputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.TraitedSpec`

## mriqc.interfaces.viz module

class `mriqc.interfaces.viz.` `PlotFD`(**inputs)

  Bases: `nipype.interfaces.base.BaseInterface`

  Plots the frame displacement of a dataset

  `input_spec`

    alias of `PlotFDInputSpec`

  `output_spec`

    alias of `PlotFDOutputSpec`

class `mriqc.interfaces.viz.` `PlotFDInputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.BaseInterfaceInputSpec`

class `mriqc.interfaces.viz.` `PlotFDOutputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.TraitedSpec`

class `mriqc.interfaces.viz.` `PlotMosaic`(**inputs)

  Bases: `nipype.interfaces.base.BaseInterface`

  Plots slices of a 3D volume into a pdf file

  `input_spec`

    alias of `PlotMosaicInputSpec`

  `output_spec`

    alias of `PlotMosaicOutputSpec`

class `mriqc.interfaces.viz.` `PlotMosaicInputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.BaseInterfaceInputSpec`

class `mriqc.interfaces.viz.` `PlotMosaicOutputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.TraitedSpec`

class `mriqc.interfaces.viz.` `Report`(**inputs)

  Bases: `nipype.interfaces.base.BaseInterface`

  `input_spec`

    alias of `ReportInputSpec`

  `output_spec`

    alias of `ReportOutputSpec`

class `mriqc.interfaces.viz.` `ReportInputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.BaseInterfaceInputSpec`

class `mriqc.interfaces.viz.` `ReportOutputSpec`(**kwargs)

  Bases: `nipype.interfaces.base.TraitedSpec`

## mriqc.interfaces.viz_utils module

`mriqc.interfaces.viz_utils.` `plot_all`(df, groups, subject=None, figsize=(11.69, 5), strip_nsubj=10, title='Summary report')

`mriqc.interfaces.viz_utils.` `plot_dist`(main_file, mask_file, xlabel, distribution=None, xlabel2=None, figsize=(11.7, 8.3))

`mriqc.interfaces.viz_utils.` `plot_fd`(fd_file, title='FD plot', mean_fd_dist=None, figsize=(11.7, 8.3))

`mriqc.interfaces.viz_utils.` `plot_measures`(df, measures, ncols=4, title='Group level report', subject=None, figsize=(8.27, 11.69))

`mriqc.interfaces.viz_utils.` `plot_mosaic`(nifti_file, title=None, overlay_mask=None, figsize=(11.7, 8.3))

`mriqc.interfaces.viz_utils.` `plot_vline`(cur_val, label, ax)

## Module contents